@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #--------------------------------------------------------------------------------
-#www2sms.py, www2sms_gui.py, www2sms_providers.py, www2sms_gui.ui v0.1b
+#www2sms.py v0.2.0
 #Copyright Bjoern Olausson
 #--------------------------------------------------------------------------------
 #This program is free software; you can redistribute it and/or modify
@@ -23,9 +23,12 @@
 #--------------------------------------------------------------------------------
 #
 
-import os, errno, pwd, sys, math, sqlite3, time, calendar, evolution
+import os, errno, pwd, sys, math, sqlite3, time, calendar, evolution, re
 from PyQt4 import QtCore, QtGui
-from www2sms_gui import *
+from www2sms_gui_main import *
+from www2sms_gui_widget_account import *
+from www2sms_gui_widget_advanced import *
+from www2sms_gui_dialog_progress import Ui_Form_Progress
 import www2sms_providers
 
 USER = pwd.getpwuid(os.getuid())[0]
@@ -52,68 +55,88 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 		self.comboBox_contact_populate()
 		# Populate the available Providers
 		for value in list_providers:
-			self.ui.comboBox_SetupProvider.addItem(value)
+			AccSet.ui.comboBox_SetupProvider.addItem(value)
 		CT = time.localtime(time.time())
 		# Set the year for scheduling SMS. From now to the next three years
 		YEAR = CT[0]
 		for YEARS in range(YEAR,YEAR + 3, 1):
-			self.ui.comboBox_AdvancedScheduleStartYear.addItem(str(YEARS))
-			self.ui.comboBox_AdvancedScheduleStopYear.addItem(str(YEARS))
+			AdvSet.ui.comboBox_AdvancedScheduleStartYear.addItem(str(YEARS))
+			AdvSet.ui.comboBox_AdvancedScheduleStopYear.addItem(str(YEARS))
 		# Try to update the GUI to the last used Account, else skip this
 		try:
 			PROVIDER, ALIAS, LOGIN, PASSWORD = c.execute('SELECT provider, alias, login, password FROM login WHERE last=1').fetchall()[0]
 			# Populate all Acounts
-			ACCOUNTS = c.execute('SELECT alias FROM login').fetchall()
-			for a in ACCOUNTS:
-				self.ui.comboBox_SetupAlias.addItem(a[0])
+			self.ACCOUNTS = c.execute('SELECT alias FROM login').fetchall()
+			for a in self.ACCOUNTS:
+				AccSet.ui.comboBox_SetupAlias.addItem(a[0])
 			# Update the GUI
 			# Updating the the Provider ComboBox
-			provider_index = self.ui.comboBox_SetupProvider.findText(PROVIDER)
-			self.ui.comboBox_SetupProvider.setCurrentIndex(provider_index)
+			provider_index = AccSet.ui.comboBox_SetupProvider.findText(PROVIDER)
+			AccSet.ui.comboBox_SetupProvider.setCurrentIndex(provider_index)
 			# Updating the the Alias ComboBox
-			alias_index = self.ui.comboBox_SetupAlias.findText(ALIAS)
-			self.ui.comboBox_SetupAlias.setCurrentIndex(alias_index)
+			alias_index = AccSet.ui.comboBox_SetupAlias.findText(ALIAS)
+			AccSet.ui.comboBox_SetupAlias.setCurrentIndex(alias_index)
 			# Updating the lineEdit Alias
-			self.ui.lineEdit_SetupNewAlias.setText(ALIAS)
+			AccSet.ui.lineEdit_SetupNewAlias.setText(ALIAS)
 			# Updating the lineEdit Login
-			self.ui.lineEdit_SetupLogin.setText(LOGIN)
+			AccSet.ui.lineEdit_SetupLogin.setText(LOGIN)
 			# Updating the lineEdit Pasword
 			#PASSWORD = base64.b64decode(PASSWORD)
-			self.ui.lineEdit_SetupPassword.setText(PASSWORD)
+			AccSet.ui.lineEdit_SetupPassword.setText(PASSWORD)
 		except IndexError:
 			provider_index = -1
+			self.ACCOUNTS = False
 
 		# Connect to some buttons and make them execute a method of the class MainWindow
 		QtCore.QObject.connect(self.ui.pushButton_Send, QtCore.SIGNAL("clicked()"), self.on_send_clicked)
 		QtCore.QObject.connect(self.ui.comboBox_contact, QtCore.SIGNAL("activated(QString)"), self.comboBox_contact_itemActivated)
 		QtCore.QObject.connect(self.ui.comboBox_number, QtCore.SIGNAL("activated(QString)"), self.comboBox_number_itemActivated)
-		QtCore.QObject.connect(self.ui.pushButton_SetupSave, QtCore.SIGNAL("clicked()"), self.on_SetupSave_clicked)
+		QtCore.QObject.connect(AccSet.ui.pushButton_SetupSave, QtCore.SIGNAL("clicked()"), self.on_SetupSave_clicked)
 		QtCore.QObject.connect(self.ui.plainTextEdit_SMS, QtCore.SIGNAL("textChanged()"), self.UpdateChars)
-		QtCore.QObject.connect(self.ui.comboBox_SetupAlias, QtCore.SIGNAL("activated(QString)"), self.on_SetupAlias_activated)
-		QtCore.QObject.connect(self.ui.pushButton_SetupDelete, QtCore.SIGNAL("clicked()"), self.on_SetupDelete_clicked)
-		QtCore.QObject.connect(self.ui.comboBox_AdvancedScheduleStartMonth, QtCore.SIGNAL("activated(QString)"), self.on_StartDate_changed)
-		QtCore.QObject.connect(self.ui.comboBox_AdvancedScheduleStopMonth, QtCore.SIGNAL("activated(QString)"), self.on_StopDate_changed)
-		QtCore.QObject.connect(self.ui.comboBox_AdvancedScheduleStartYear, QtCore.SIGNAL("activated(QString)"), self.on_StartDate_changed)
-		QtCore.QObject.connect(self.ui.comboBox_AdvancedScheduleStopYear, QtCore.SIGNAL("activated(QString)"), self.on_StopDate_changed)
+		QtCore.QObject.connect(AccSet.ui.comboBox_SetupAlias, QtCore.SIGNAL("activated(QString)"), self.on_SetupAlias_activated)
+		QtCore.QObject.connect(AccSet.ui.pushButton_SetupDelete, QtCore.SIGNAL("clicked()"), self.on_SetupDelete_clicked)
+		QtCore.QObject.connect(AdvSet.ui.comboBox_AdvancedScheduleStartMonth, QtCore.SIGNAL("activated(QString)"), self.on_StartDate_changed)
+		QtCore.QObject.connect(AdvSet.ui.comboBox_AdvancedScheduleStopMonth, QtCore.SIGNAL("activated(QString)"), self.on_StopDate_changed)
+		QtCore.QObject.connect(AdvSet.ui.comboBox_AdvancedScheduleStartYear, QtCore.SIGNAL("activated(QString)"), self.on_StartDate_changed)
+		QtCore.QObject.connect(AdvSet.ui.comboBox_AdvancedScheduleStopYear, QtCore.SIGNAL("activated(QString)"), self.on_StopDate_changed)
 		self.enableTabs(provider_index)
-
+		QtCore.QObject.connect(self.ui.actionAdv_Provider_Settings, QtCore.SIGNAL("triggered(bool)"), self.ShowDialogAdv)
+		QtCore.QObject.connect(self.ui.actionAccount_Setup, QtCore.SIGNAL("triggered(bool)"), self.ShowDialogAccSet)
 	def enableTabs(self, provider_index):
-		# Enable the SMS tab if we have an account, otherwise not
-		ALIAS = unicode(self.ui.comboBox_SetupAlias.currentText())
-		idx = self.ui.tabWidget.indexOf(self.ui.Tab_SMS)
-		if ALIAS:
-			self.ui.tabWidget.setTabEnabled(idx, True)
+		## Enable the SMS SEND Button if we have an account, otherwise not
+		if self.ACCOUNTS:
+			self.ui.pushButton_Send.show()
 		else:
-			self.ui.tabWidget.setTabEnabled(idx, False)
-		# Enable the "advanced" options if supported
-		idx = self.ui.tabWidget.indexOf(self.ui.Tab_Advanced)
+			self.ui.pushButton_Send.hide()
+		## Enable the "advanced" options if supported
 		if (provider_index >= 0) and providers[provider_index].hasAdvancedFeatures():
-			self.ui.tabWidget.setTabEnabled(idx, True)
+			self.ui.actionAdv_Provider_Settings.setEnabled(True)
 		else:
-			self.ui.tabWidget.setTabEnabled(idx, False)
+			self.ui.actionAdv_Provider_Settings.setDisabled(True)
+
+	def ShowDialogAdv(self):
+	    	PROVIDER = AccSet.ui.comboBox_SetupProvider.currentText()
+	    	# TODO: When there are more providers, a GUI element should be created for every
+	    	# TODO: advanced setting. For now only o2online.de has such settings, so AdvSet
+	    	# TODO: can be considered the GUI for o2online advanced settings. Thats why we set
+	    	# TODO: PROVIDER = 'AdvSet'
+	    	PROVIDER = 'AdvSet'
+	    	# Dictionary of all available UIs for advanced settings.
+		p_dict = {'AdvSet' : AdvSet.show}
+		p_dict[PROVIDER]()
+		# TODO: Check wy the sheduling for o2online.de is not working.
+		# TODO: Meanwhile this is disabled.
+		AdvSet.ui.groupBox_AdvancedSchedule.setDisabled(True)
+
+	def ShowDialogAccSet(self):
+		AccSet.show()
 
 	# Class wich is called to get the contacts from the evolution backend
 	def comboBox_contact_populate(self):
+	    	# TODO: Find out why Umlaute like "ä,ö,ü,ß" are garbled.
+		# Regular expression to find all phone numbers in the vCard
+		re_tel = re.compile('TEL;TYPE')
+
 		name_attributes = [
 			"full-name",
 			"given-name",
@@ -148,33 +171,50 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 
 		abook = evolution.ebook.open_addressbook("default")
 		contacts = abook.get_all_contacts()
-		#help(contacts)
 		contacts.sort(key=lambda obj: obj.get_property(name_attributes[2]))
 
 		for econtact in contacts:
-			#help(econtact)
-			single_contact = [econtact.get_property(name_attributes[2]), econtact.get_property(name_attributes[1])]
-			for phone_attribute in phone_attributes:
-				single_contact_numbers.append(econtact.get_property(phone_attribute))
+			single_contact = [econtact.get_property(name_attributes[2]), econtact.get_property(name_attributes[1]), econtact.get_property(name_attributes[3])]
+			vcard = econtact.get_vcard_string()
+			for line in vcard.split('\n'):
+				if re_tel.search(line):
+					single_contact_numbers.append(line.split(':')[1].strip())
 			self.contact_list.append(single_contact)
 			self.phone_list.append(single_contact_numbers)
 			single_contact = []
 			single_contact_numbers = []
+
 		for contact in self.contact_list:
-			item = "%s, %s" %(contact[0], contact[1])
+			if contact[0] and contact[1]:
+				item = "%s, %s" %(contact[0], contact[1])
+			elif contact[0] and not contact[1]:
+				item = "%s" %(contact[0])
+			elif not contact[0] and contact[1]:
+				item = "%s" %(contact[1])
+			elif not contact[0] and not contact[1] and contact[2]:
+				item = "%s" %(contact[2])
+			else:
+				item = "No name available"
 			self.ui.comboBox_contact.addItem(item)
 
 	def comboBox_contact_itemActivated(self):
 		self.ui.comboBox_number.clear()
 		contact_index = self.ui.comboBox_contact.currentIndex()
-		print contact_index
-		print self.phone_list[contact_index]
-		for item in self.phone_list[contact_index]:
-			try:
-				self.ui.comboBox_number.addItem(item)
-			except:
-				pass
-		self.ui.lineEdit_Number.setText(self.phone_list[contact_index][11])
+		if len(self.phone_list[contact_index]) == 0:
+			self.ui.comboBox_number.addItem('No number available')
+		else:
+			for item in self.phone_list[contact_index]:
+				try:
+					if not item:
+						self.ui.comboBox_number.addItem('No number available')
+					else:
+						self.ui.comboBox_number.addItem(item)
+				except:
+					pass
+		if len(self.phone_list[contact_index]) == 0:
+			self.ui.lineEdit_Number.setText('No number available')
+		else:
+			self.ui.lineEdit_Number.setText(self.phone_list[contact_index][0])
 
 	def comboBox_number_itemActivated(self):
 		item = self.ui.comboBox_number.currentText()
@@ -213,18 +253,18 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 	# Method which updates the GUI to the Account selected in comboBox_SetupAlias
 	def on_SetupAlias_activated(self):
 		# Get the selected Account
-		ALIAS = unicode(self.ui.comboBox_SetupAlias.currentText())
+		ALIAS = unicode(AccSet.ui.comboBox_SetupAlias.currentText())
 		# Read the settings for the selected Account fom DB
 		try:
 			PROVIDER, ALIAS, LOGIN, PASSWORD = c.execute('SELECT provider, alias, login, password FROM login WHERE alias=?', (ALIAS,)).fetchall()[0]
 		except IndexError:
 			pass
 		# Update the GUI elements
-		provider_index = self.ui.comboBox_SetupProvider.findText(PROVIDER)
-		self.ui.comboBox_SetupProvider.setCurrentIndex(provider_index)
-		self.ui.lineEdit_SetupNewAlias.setText(ALIAS)
-		self.ui.lineEdit_SetupLogin.setText(LOGIN)
-		self.ui.lineEdit_SetupPassword.setText(PASSWORD)
+		provider_index = AccSet.ui.comboBox_SetupProvider.findText(PROVIDER)
+		AccSet.ui.comboBox_SetupProvider.setCurrentIndex(provider_index)
+		AccSet.ui.lineEdit_SetupNewAlias.setText(ALIAS)
+		AccSet.ui.lineEdit_SetupLogin.setText(LOGIN)
+		AccSet.ui.lineEdit_SetupPassword.setText(PASSWORD)
 		self.enableTabs(provider_index)
 		# Remove the last account flag to set it on the new/updated profile
 		c.execute('UPDATE login SET last=0 WHERE last=1')
@@ -235,52 +275,52 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 	# Well, this is obvious, isn't it? Okay, it deletes the current selected account.
 	def on_SetupDelete_clicked(self):
 		# Get the current selected Account
-		ALIAS = unicode(self.ui.comboBox_SetupAlias.currentText())
+		ALIAS = unicode(AccSet.ui.comboBox_SetupAlias.currentText())
 		# Delete it from the DB
 		c.execute('DELETE FROM login WHERE alias=?', (ALIAS,))
 		conn.commit()
 		# Remove the Account from comboBox_SetupAlias
-		alias_index = self.ui.comboBox_SetupAlias.findText(ALIAS)
-		self.ui.comboBox_SetupAlias.removeItem(alias_index)
+		alias_index = AccSet.ui.comboBox_SetupAlias.findText(ALIAS)
+		AccSet.ui.comboBox_SetupAlias.removeItem(alias_index)
 		# Check if there is something left in the DB
 		ROWS = c.execute('SELECT alias FROM login').rowcount
 		# Update the GUI elements
 		if ROWS == -1:
-			self.ui.lineEdit_SetupNewAlias.clear()
-			self.ui.lineEdit_SetupLogin.clear()
-			self.ui.lineEdit_SetupPassword.clear()
+			AccSet.ui.lineEdit_SetupNewAlias.clear()
+			AccSet.ui.lineEdit_SetupLogin.clear()
+			AccSet.ui.lineEdit_SetupPassword.clear()
 			self.enableTabs(-1)
 		else:
-			self.on_SetupAlias_activated()
-		QtGui.QMessageBox.information(self, 'www2sms', "Account %s deleted" %(ALIAS))
+			AccSet.on_SetupAlias_activated()
+		QtGui.QMessageBox.information(AccSet, 'www2sms', "Account %s deleted" %(ALIAS))
 
 	# Method which is called, when an account is created/updated
 	def on_SetupSave_clicked(self):
 		# Gather Account information
-		PROVIDER = unicode(self.ui.comboBox_SetupProvider.currentText())
-		ALIAS = unicode(self.ui.lineEdit_SetupNewAlias.text())
-		LOGIN = unicode(self.ui.lineEdit_SetupLogin.text())
-		PASSWORD = unicode(self.ui.lineEdit_SetupPassword.text())
+		PROVIDER = unicode(AccSet.ui.comboBox_SetupProvider.currentText())
+		ALIAS = unicode(AccSet.ui.lineEdit_SetupNewAlias.text())
+		LOGIN = unicode(AccSet.ui.lineEdit_SetupLogin.text())
+		PASSWORD = unicode(AccSet.ui.lineEdit_SetupPassword.text())
 		# Remove the last account flag to set it on the new/updated profile
 		c.execute('UPDATE login SET last=0 WHERE last=1')
 		# Check if Account exist, if it exists, we update the content in the DB on save, else we add it
 		EXIST = c.execute('select alias FROM login WHERE alias=?', (ALIAS,)).fetchall()
 		if len(EXIST) != 0:
-		    c.execute('UPDATE login SET provider=?, login=?, password=?, last=1 WHERE alias=?', (PROVIDER, LOGIN, PASSWORD, ALIAS))
+			c.execute('UPDATE login SET provider=?, login=?, password=?, last=1 WHERE alias=?', (PROVIDER, LOGIN, PASSWORD, ALIAS))
 		else:
-		    c.execute('INSERT INTO login VALUES (NULL, ?, ?, ?, ?, 1)', (PROVIDER, ALIAS, LOGIN, PASSWORD))
-		    # Add the new Account to comboBox_SetupAlias
-		    self.ui.comboBox_SetupAlias.addItem(ALIAS)
+			c.execute('INSERT INTO login VALUES (NULL, ?, ?, ?, ?, 1)', (PROVIDER, ALIAS, LOGIN, PASSWORD))
+			# Add the new Account to comboBox_SetupAlias
+		    	AccSet.ui.comboBox_SetupAlias.addItem(ALIAS)
 		conn.commit()
 		# Let the user know that we have saved the the account/changes
-		QtGui.QMessageBox.information(self, 'www2sms', "saved")
+		QtGui.QMessageBox.information(AccSet, 'www2sms', "saved")
 		# Update the GUI
-		alias_index = self.ui.comboBox_SetupAlias.findText(ALIAS)
-		self.ui.comboBox_SetupAlias.setCurrentIndex(alias_index)
-		provider_index = self.ui.comboBox_SetupProvider.findText(PROVIDER)
-		self.ui.comboBox_SetupProvider.setCurrentIndex(provider_index)
-		self.ui.lineEdit_SetupLogin.setText(LOGIN)
-		self.ui.lineEdit_SetupPassword.setText(PASSWORD)
+		alias_index = AccSet.ui.comboBox_SetupAlias.findText(ALIAS)
+		AccSet.ui.comboBox_SetupAlias.setCurrentIndex(alias_index)
+		provider_index = AccSet.ui.comboBox_SetupProvider.findText(PROVIDER)
+		AccSet.ui.comboBox_SetupProvider.setCurrentIndex(provider_index)
+		AccSet.ui.lineEdit_SetupLogin.setText(LOGIN)
+		AccSet.ui.lineEdit_SetupPassword.setText(PASSWORD)
 		self.enableTabs(provider_index)
 
 	# Method which is called when we want to send the sms. It actually calls a method on the providers class
@@ -290,46 +330,46 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 		reply = QtGui.QMessageBox.question(self, 'Send SMS?', "Are you sure?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
 		# If reply is YES, we send the SMS, else we just do nothing
 		if reply == QtGui.QMessageBox.Yes:
-		    	# Read Scheduling settings if activated
-
+			self.Stat = FormPro()
+		    # Read Scheduling settings if activated
 			SCHEDULE = []
-			if self.ui.checkBox_AdvancedScheduleRepeat.isChecked():
+			if AdvSet.ui.checkBox_AdvancedScheduleRepeat.isChecked():
 				# SCHEDULE Layout: ([RECURRENCY, STOPTrueFalse], [YEARstart, YEARstop], [MONTHstart, MONTHstop], [DAYstart, DAYstop], [HOUREstart, HOUREstop], [MINUTEstart, MINUTEstop])
-				SCHEDULE.append([ str(self.ui.comboBox_AdvancedRecurrence.currentText()), self.ui.checkBox_AdvancedScheduleStop.isChecked() ])
-				SCHEDULE.append([ str(self.ui.comboBox_AdvancedScheduleStartYear.currentText()), str(self.ui.comboBox_AdvancedScheduleStopYear.currentText()) ])
-				SCHEDULE.append([ str(self.ui.comboBox_AdvancedScheduleStartMonth.currentText()), str(self.ui.comboBox_AdvancedScheduleStopMonth.currentText()) ])
-				SCHEDULE.append([ str(self.ui.comboBox_AdvancedScheduleStartDay.currentText()), str(self.ui.comboBox_AdvancedScheduleStopDay.currentText()) ])
-				SCHEDULE.append([ str(self.ui.comboBox_AdvancedScheduleStartHoure.currentText()), str(self.ui.comboBox_AdvancedScheduleStopHoure.currentText()) ])
-				SCHEDULE.append([ str(self.ui.comboBox_AdvancedScheduleStartMinute.currentText()), str(self.ui.comboBox_AdvancedScheduleStopMinute.currentText()) ])
+				SCHEDULE.append([ str(AdvSet.ui.comboBox_AdvancedRecurrence.currentText()), self.ui.checkBox_AdvancedScheduleStop.isChecked() ])
+				SCHEDULE.append([ str(AdvSet.ui.comboBox_AdvancedScheduleStartYear.currentText()), str(AdvSet.ui.comboBox_AdvancedScheduleStopYear.currentText()) ])
+				SCHEDULE.append([ str(AdvSet.ui.comboBox_AdvancedScheduleStartMonth.currentText()), str(AdvSet.ui.comboBox_AdvancedScheduleStopMonth.currentText()) ])
+				SCHEDULE.append([ str(AdvSet.ui.comboBox_AdvancedScheduleStartDay.currentText()), str(AdvSet.ui.comboBox_AdvancedScheduleStopDay.currentText()) ])
+				SCHEDULE.append([ str(AdvSet.ui.comboBox_AdvancedScheduleStartHoure.currentText()), str(AdvSet.ui.comboBox_AdvancedScheduleStopHoure.currentText()) ])
+				SCHEDULE.append([ str(AdvSet.ui.comboBox_AdvancedScheduleStartMinute.currentText()), str(AdvSet.ui.comboBox_AdvancedScheduleStopMinute.currentText()) ])
 			else:
 				SCHEDULE = False
 
 			# Read Sender
-			if self.ui.radioButton_AdvancedMyMobileNumber.isChecked():
+			if AdvSet.ui.radioButton_AdvancedMyMobileNumber.isChecked():
 				SENDER = "MyNumber"
-			elif self.ui.radioButton_AdvancedAnonym.isChecked():
+			elif AdvSet.ui.radioButton_AdvancedAnonym.isChecked():
 				SENDER = "Anonym"
-			elif self.ui.radioButton_AdvancedText.isChecked():
+			elif AdvSet.ui.radioButton_AdvancedText.isChecked():
 				SENDER = self.ui.lineEdit_AdvancedText.text()
 
 			# Read Special
-			FLASH = self.ui.checkBox_AdvancedFlashSMS.isChecked()
-
+			FLASH = AdvSet.ui.checkBox_AdvancedFlashSMS.isChecked()
 			# Read the login
-			LOGIN = unicode(self.ui.lineEdit_SetupLogin.text())
+			LOGIN = unicode(AccSet.ui.lineEdit_SetupLogin.text())
 			# Read the password
-			PASSWORD = unicode(self.ui.lineEdit_SetupPassword.text())
+			PASSWORD = unicode(AccSet.ui.lineEdit_SetupPassword.text())
 			# Read the number to which we send the SMS
 			NUMBER = unicode(self.ui.lineEdit_Number.text())
 			# Read the text we want to send
 			SMSTEXT = unicode(self.ui.plainTextEdit_SMS.toPlainText())
 			# Read the provider to use
-			PROVIDER = unicode(self.ui.comboBox_SetupProvider.currentText())
+			PROVIDER = unicode(AccSet.ui.comboBox_SetupProvider.currentText())
 			# Get the provder
-			provider_index = self.ui.comboBox_SetupProvider.findText(PROVIDER)
+			provider_index = AccSet.ui.comboBox_SetupProvider.findText(PROVIDER)
 			provider = providers[provider_index]
 			# send the SMS
-			STATUS, MSG = provider.sendSMS(NUMBER, SMSTEXT, LOGIN, PASSWORD, SCHEDULE, SENDER, FLASH)
+			STATUS, MSG = provider.sendSMS(self, app, NUMBER, SMSTEXT, LOGIN, PASSWORD, SCHEDULE, SENDER, FLASH)
+			self.Stat.close()
 			if STATUS:
 				self.on_send_success(MSG)
 			else:
@@ -346,6 +386,30 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 	def on_send_failed(self,MSG):
 		QtGui.QMessageBox.warning(self, 'www2sms', MSG)
 
+def DialogStatusMessage(self, statusmessage):
+	QtGui.QMessageBox.information(self, 'www2sms', statusmessage)
+
+class FormAccount(QtGui.QDialog, Ui_FormAccount):
+	def __init__(self, win_parent = None):
+		#Init the base class
+		QtGui.QDialog.__init__(self, win_parent)
+		self.ui = Ui_FormAccount()
+		self.ui.setupUi(self)
+
+class FormAdv(QtGui.QDialog, Ui_FormAdvanced):
+	def __init__(self, win_parent = None):
+		#Init the base class
+		QtGui.QDialog.__init__(self, win_parent)
+		self.ui = Ui_FormAdvanced()
+		self.ui.setupUi(self)
+
+class FormPro(QtGui.QDialog, Ui_Form_Progress):
+	def __init__(self, win_parent = None):
+		#Init the base class
+		QtGui.QDialog.__init__(self, win_parent)
+		self.ui = Ui_Form_Progress()
+		self.ui.setupUi(self)
+
 def mk_db():
     try:
 	os.makedirs(CONFIG_DIR, 0755)
@@ -378,6 +442,12 @@ if __name__ == "__main__":
 	# Someone is launching this directly
 	# Create the QApplication
 	app = QtGui.QApplication(sys.argv)
+	#The Status Form
+	#Stat = FormPro()
+	#The Account Form
+	AccSet = FormAccount()
+	#The O2 Advanced Form
+	AdvSet = FormAdv()
 	#The Main window
 	ui = MainWindow()
 	ui.show()
