@@ -1,10 +1,25 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import sys, re, mechanize, cookielib, base64, urllib2
+import sys, re, mechanize, cookielib, base64, urllib2, time
+from www2sms_gui_dialog_captcha import *
+from PyQt4 import QtCore, QtGui
+
+def UpdatePbar(self, MainWindow, app, value, label):
+	MainWindow.Stat.ui.label.setText(label)
+	MainWindow.Stat.ui.progressBar.setProperty("value", value)
+	app.processEvents()
+
+
+class ShowCAPTCHA(QtGui.QDialog, Ui_DialogCaptcha):
+	def __init__(self, win_parent = None):
+		#Init the base class
+		QtGui.QDialog.__init__(self, win_parent)
+		self.ui = Ui_DialogCaptcha()
+		self.ui.setupUi(self)
 
 # Class which holds the provider methods.
-class provider:
+class provider():
 	# get the printable name for this provider
 	def getName(self):
 		raise Exception('provider class is a base class only')
@@ -14,7 +29,7 @@ class provider:
 	def hasAdvancedFeatures(self):
 		return False
 	# send the sms
-	def sendSMS(self, NUMBER, SMSTEXT, LOGIN, PASSWORD, SCHEDULE=None, SENDER=None, FLASH=None):
+	def sendSMS(self, app, NUMBER, SMSTEXT, LOGIN, PASSWORD, SCHEDULE=None, SENDER=None, FLASH=None):
 		return False, "SMS sending not implemented"
 
 # o2online.de 1.0
@@ -23,20 +38,25 @@ class provider_o2online_de(provider):
 		return 'o2online (Deutschland)'
 	def hasAdvancedFeatures(self):
 		return True
-	def sendSMS(self, NUMBER, SMSTEXT, LOGIN, PASSWORD, SCHEDULE=None, SENDER=None, FLASH=None):
+	def sendSMS(self, MainWindow, app, NUMBER, SMSTEXT, LOGIN, PASSWORD, SCHEDULE=None, SENDER=None, FLASH=None):
 		LOGINURL = 'http://www.o2online.de/'
 		execute = True
-		if execute:
+		MainWindow.Stat.ui.progressBar.setMinimum(0)
+		MainWindow.Stat.ui.progressBar.setMaximum(10)
 
+		if execute:
 			# RegExp to check if SMS was send successfully:
 			re_suc = re.compile('Ihre SMS wurde erfolgreich versendet', re.IGNORECASE)
-
 			# RegEx to check if en error occured
 			re_fail = re.compile('(Fehler beim Login)|(Error logging in)', re.IGNORECASE)
 			# RegExp to find the link to the communication center:
 			com = re.compile('comcenter')
+			# RegExp to find the sucking CAPTCHA image
+			re_cap = re.compile('jcaptchaReg')
 
 			# Instanziate a Browser
+			print "Initiating the browser"
+			UpdatePbar(self, MainWindow, app, "1", "Initiating the browser")
 			brw = mechanize.Browser()
 
 			# Instanziate Cookie Jar
@@ -69,31 +89,33 @@ class provider_o2online_de(provider):
 			brw.addheaders = [('User-agent', 'Opera/9.80 (Linux x86_64; U; en) Presto/2.5.18 Version/10.50 Gentoo')]
 
 			# Open the O2 website
+			print "Open Website"
+			UpdatePbar(self, MainWindow, app, "2", "Open Website")
 			brw.open(LOGINURL)
 
-			# Show the available forms
-			#n = 0
-			#for f in br.forms():
-			    #print "--------FORM=%s------------" %(n)
-			    #print f
-			    #print "---------------------------"
-			    #n += 1
-
 			# Select the Login form
+			print "Select Login Form"
+			UpdatePbar(self, MainWindow, app, "3", "Select Login Form")
 			brw.select_form(name='loginForm')
 
 			# Get the URL to the Communication Center
+			print "Get the URL to the Communication Center"
+			UpdatePbar(self, MainWindow, app, "4", "Get the URL to the Communication Center")
 			for item in brw.form.find_control("url", type="select").items:
 			    if com.search(str(item)):
 				COMMURL = str(item)
 
 			# Check that COMURL is not empty
+			print "Check that COMURL is not empty"
+			UpdatePbar(self, MainWindow, app, "5", "Check that COMURL is not empty")
 			try:
 			    COMMURL
 			except:
 			    raise Exception("Failed to get URL to Communication Center")
 
 			# Fill in User credentials
+			print "Fill in User credentials"
+			UpdatePbar(self, MainWindow, app, "6", "Fill in User credentials")
 			brw.form['loginName'] = LOGIN
 			#brw.form['password'] = base64.b64decode(PASSWORD)
 			brw.form['password'] = PASSWORD
@@ -101,6 +123,8 @@ class provider_o2online_de(provider):
 			#brw.form.set_value([COMMURL], name="url")
 
 			# Login
+			print "Loging in"
+			UpdatePbar(self, MainWindow, app, "7", "Loging in")
 			try:
 				brw.submit()
 			except:
@@ -110,22 +134,94 @@ class provider_o2online_de(provider):
 				raise Exception("Login fehlgeschlagen")
 
 			result = brw.response().read()
-			print result
-			log = open("submit.html", "w")
-			log.write(str(result))
-			log.close()
+			#print result
+			#log = open("submit.html", "w")
+			#log.write(str(result))
+			#log.close()
+
+			#check for CAPTCHA
+			print "CAPTCHA-Check"
+			UpdatePbar(self, MainWindow, app, "8", "CAPTCHA-Check")
+			while re_cap.search(str(result)):
+				#Instaciate the CAPTCHA dialog
+				sc = ShowCAPTCHA()
+
+				## Download the CAPTCHA with urllib2
+				#current_url = brw.geturl()
+				#base_url = current_url[:current_url.rfind("/")]
+				#dl_captcha = urllib2.urlopen("%s/jcaptchaReg" %(base_url))
+				#qimg = QtGui.QImage.fromData(dl_captcha.read())
+				#pixmap = QtGui.QPixmap.fromImage(qimg)
+
+				## Download the CAPTCHA with urllib2 and save to jpg
+				#current_url = brw.geturl()
+				#base_url = current_url[:current_url.rfind("/")]
+				#dl_captcha = urllib2.urlopen("%s/jcaptchaReg" %(base_url))
+				#captcha = open("captcha.jpg", 'wb')
+				#captcha.write(dl_captcha.read())
+				#captcha.close()
+				#pixmap = QtGui.QPixmap('captcha.jpg')
+
+				## Download CAPTCHA with mechanize
+				current_url = brw.geturl()
+				base_url = current_url[:current_url.rfind("/")]
+				dl_captcha = brw.open("%s/jcaptchaReg" %(base_url)).read(4096*10)
+				qimg = QtGui.QImage.fromData(dl_captcha)
+				pixmap = QtGui.QPixmap.fromImage(qimg)
+				brw.back()
+
+				## Download CAPTCHA with mechanize and save to file
+				#current_url = brw.geturl()
+				#base_url = current_url[:current_url.rfind("/")]
+				#dl_captcha = brw.open("%s/jcaptchaReg" %(base_url)).read(4096*10)
+				#captcha = open("captcha.jpg", 'wb')
+				#captcha.write(dl_captcha)
+				#captcha.close()
+				#pixmap = QtGui.QPixmap('captcha.jpg')
+
+				#Set captcha.jpg to show up in the CAPTCHA dialog
+				sc.ui.label_captcha.setPixmap(pixmap)
+				def getcaptcha():
+					self.captchatext = unicode(sc.ui.lineEdit_captcha.text())
+				QtCore.QObject.connect(sc.ui.buttonBox_Captcha, QtCore.SIGNAL("accepted()"), getcaptcha)
+				sc.show()
+				sc.exec_()
+				brw.select_form(name='riddle')
+				print self.captchatext
+				brw.form["riddleValue"] = self.captchatext
+				try:
+					brw.submit()
+				except:
+					STATUS = False
+					MSG = "Kommunikationsfehler"
+					return STATUS, MSG
+					raise Exception("Kommunikationsfehler")
+
+				result = brw.response().read()
+				if re_cap.search(str(result)):
+					reply = QtGui.QMessageBox.question(MainWindow, 'CAPTCHA verifikation fehlgeschlagen!', "Nochmal versuchen?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+					if reply == QtGui.QMessageBox.No:
+						STATUS = False
+						MSG = "CAPTCHA verifikation abgebrochen durch User"
+						return STATUS, MSG
+						raise Exception("UserQuitCaptchaVerification")
+
+
 			if re_fail.search(str(result)):
-			    STATUS = False
-			    MSG = "Login fehlgeschlagen oder nicht registriert"
-			    return STATUS, MSG
-			    raise Exception("Login fehlgeschlagen oder nicht registriert")
+				STATUS = False
+				MSG = "Login fehlgeschlagen oder nicht registriert"
+				return STATUS, MSG
+				raise Exception("Login fehlgeschlagen oder nicht registriert")
 
 			# Open the SMS Center (ISO-8859-1)
+			print "Open the SMS Center"
+			UpdatePbar(self, MainWindow, app, "9", "Open the SMS Center")
 			brw.open('https://email.o2online.de/smscenter_new.osp')
 			res = brw.response()
 			ENCODING = res.info()["Content-type"].split()[1].split("=")[1]
 
 			try:
+				print "Select SMS form"
 				brw.select_form(name='frmSMS')
 			except:
 				STATUS = False
@@ -147,9 +243,6 @@ class provider_o2online_de(provider):
 				print "Sending SMS with \"%s\" as sender" %(SENDER)
 				brw.form['FlagDefSender'] = '1'
 				brw.form['SMSFrom'] = str(SENDER)
-			# If Schedule is not selected: SCHEDULE = False
-			# else:
-			# SCHEDULE = ([RECURRENCY, STOP(True/False)], [YEARstart, YEARstop], [MONTHstart, MONTHstop], [DAYstart, DAYstop], [HOUREstart, HOUREstop], [MINUTEstart, MINUTEstop])
 			if SCHEDULE :
 				print "Scheduling SMS"
 				StartDate = '%s,%s,%s,%s,%s,%s' %(str(SCHEDULE[1][0]), str(SCHEDULE[2][0]), str(SCHEDULE[3][0]), str(SCHEDULE[4][0]), str(SCHEDULE[5][0]), '00')
@@ -171,6 +264,8 @@ class provider_o2online_de(provider):
 					brw.form['RepeatEndType'] = '1'
 					brw.form['RepeatEndDate'] = StopDate
 			try:
+				print "Send SMS"
+				UpdatePbar(self, MainWindow, app, "10", "Send SMS")
 				brw.submit()
 				result = brw.response().read()
 				if re_suc.search(str(result)):
@@ -181,7 +276,8 @@ class provider_o2online_de(provider):
 					MSG = 'Provider responded: Ihre SMS wurde nicht versendet'
 			except :
 				STATUS = False
-				MSG = 'Failed to submit message to O2'
+				MSG = 'Übertragung fehlgeschlagen'
+			MainWindow.Stat.close()
 			return STATUS, MSG
 			#--------FORM=3------------
 			#<frmSMS POST https://email.o2online.de/smscenter_send.osp application/x-www-form-urlencoded
@@ -226,7 +322,7 @@ class provider_vodafone_nl(provider):
 		return 'Vodefone Nederland'
 	def hasAdvancedFeatures(self):
 		return False
-	def sendSMS(self, NUMBER, SMSTEXT, LOGIN, PASSWORD, SCHEDULE=None, SENDER=None, FLASH=None):
+	def sendSMS(self, MainWindow, app, NUMBER, SMSTEXT, LOGIN, PASSWORD, SCHEDULE=None, SENDER=None, FLASH=None):
 		# TODO: synchronize number verification with main code (UpdateChars() perhaps?)
 		# TODO: block SMS longer than 1 message
 		# TODO: enforce maximum SMS size of 125 characters (*not* 160)
@@ -245,14 +341,21 @@ class provider_vodafone_nl(provider):
 		else:
 			return False, 'Only Dutch mobile phone numbers allowed'
 
+                # XXX: GUI manipulation
+		MainWindow.Stat.ui.progressBar.setMinimum(0)
+		MainWindow.Stat.ui.progressBar.setMaximum(8)
+
 		# set up our browser
+		UpdatePbar(self, MainWindow, app, "1", "Initiating the browser")
 		br = mechanize.Browser()
 		cj = cookielib.LWPCookieJar()
 		br.set_cookiejar(cj)
 
 		# login
 		try:
+			UpdatePbar(self, MainWindow, app, "2", "Connecting to login page")
 			br.open('https://my.vodafone.nl/prive/my_vodafone')
+			UpdatePbar(self, MainWindow, app, "3", "Logging in")
 			br.select_form(name='login')
 			br.form['username'] = LOGIN
 			br.form['password'] = PASSWORD
@@ -262,6 +365,7 @@ class provider_vodafone_nl(provider):
 
 
 		# verify our login worked and return error if not
+	   	UpdatePbar(self, MainWindow, app, "4", "Checking login")
 		br.response().read()
 		try:
 			br.find_link(text='Uitloggen')
@@ -269,14 +373,17 @@ class provider_vodafone_nl(provider):
 			return False, 'Login failed'
 
 		# send the SMS
+   	        UpdatePbar(self, MainWindow, app, "5", "Opening SMS page")
 		try:
 			br.open('https://my.vodafone.nl/Prive/My_Vodafone/gratis_sms_versturen')
 		except:
 			return False, 'Error opening free SMS web page'
+   	        UpdatePbar(self, MainWindow, app, "6", "Checking maximum SMS per day")
 		response = br.response().read()
 		if re.search(r'Je hebt het maximum aantal gratis SMS\'jes bereikt voor vandaag.', response):
 			return False, "Provider responded: Je hebt het maximum aantal gratis SMS'jes bereikt voor vandaag."
 
+   	        UpdatePbar(self, MainWindow, app, "7", "Sending SMS")
 		try:
 			br.select_form(name='controle')
 			br.form['phoneNumber'] = number
@@ -287,6 +394,7 @@ class provider_vodafone_nl(provider):
 			return False, 'Error submitting SMS form'
 
 		# check to see if our send worked
+   	        UpdatePbar(self, MainWindow, app, "8", "Confirming SMS sent")
 		response = br.response().read()
 		if re.search(r'Je sms\'je is verstuurd.', response):
 			return True, "Provider responded: Je sms'je is verstuurd."
@@ -294,3 +402,4 @@ class provider_vodafone_nl(provider):
 			return False, "Provider responded: Je hebt het maximum aantal gratis SMS'jes voor vandaag verstuurd."
 		else:
 			return False, 'Message not sent'
+        	MainWindow.Stat.close()
